# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ancv', 'ancv.data', 'ancv.data.models', 'ancv.visualization', 'ancv.web']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp[speedups]>=3.8.1,<4.0.0',
 'cachetools>=5.2.0,<6.0.0',
 'gidgethub>=5.1.0,<6.0.0',
 'humanize>=4.1.0,<5.0.0',
 'pydantic[email]>=1.9.1,<2.0.0',
 'rich>=12.4.4,<13.0.0',
 'structlog>=21.5.0,<22.0.0',
 'typer>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['ancv = ancv.__main__:app']}

setup_kwargs = {
    'name': 'ancv',
    'version': '0.14.1',
    'description': "Render 'JSON Resume' sources to ANSI-enriched output for terminal clients (cURL, wget, ...) to consume.",
    'long_description': '# [ancv](https://github.com/alexpovel/ancv)\n\nGetting you [an CV](https://www.youtube.com/watch?v=mJUtMEJdvqM) (*[ANSI](https://en.wikipedia.org/wiki/ANSI_escape_code)-v* 🤡) straight to your and anyone else\'s terminals.\n\nBe warned though, for this is kinda useless and just for fun:\n\n![Users Venn diagram](docs/images/users-venn.svg)\n\n## Getting started\n\n1. Create a resume according to the [JSON Resume Schema](https://jsonresume.org/schema/) (see also the [schema specification](https://github.com/jsonresume/resume-schema/blob/master/schema.json)) either:\n\n   - manually (see [this sample](./tests/test_data/resumes/full.json) for a possible starting point),\n   - exporting from [LinkedIn](https://www.linkedin.com/) using [Joshua Tzucker\'s LinkedIn exporter](https://joshuatz.com/projects/web-stuff/linkedin-profile-to-json-resume-exporter/) ([repo](https://github.com/joshuatz/linkedin-to-jsonresume)), or\n   - exporting from one of the platforms advertised as offering [JSON resume integration](https://jsonresume.org/schema/).\n2. [Create a **public** gist](https://gist.github.com/) named `resume.json` with those resume contents.\n   See [here](https://gist.github.com/alexpovel/4a94aaccdc6ed8d214d0f8a73e50a536) for a working example from the author.\n3. Try it out, using...\n   - curl:\n\n      ```bash\n      curl -L ancv.io/username\n      ```\n\n      with `-L` being shorthand for [`--location`](https://curl.se/docs/manpage.html), allowing you to follow the redirect from `http://ancv.io` through to `https://ancv.io`.\n      It\'s shorter than its also perfectly viable alternative:\n\n      ```bash\n      curl https://ancv.io/username\n      ```\n\n      Lastly, you might want to page the output for easiest reading, top-to-bottom:\n\n      ```bash\n      curl -sL ancv.io/username | less\n      ```\n\n   - wget:\n\n     ```bash\n     wget -O - --quiet ancv.io/username\n     ```\n\n     where `-O` is short for [`--output-document`](https://linux.die.net/man/1/wget), used here to redirect to stdout.\n\n   - PowerShell (5 and 7):\n\n     ```powershell\n     (iwr ancv.io/username).Content\n     ```\n\n     where `iwr` is an alias for [`Invoke-Webrequest`](https://docs.microsoft.com/en-us/powershell/module/microsoft.powershell.utility/invoke-webrequest?view=powershell-7.2), returning an object.\n\n   **For a quick, working example replace `username` with `alexpovel`.**\n\n## Configuration\n\n*All configuration is optional.*\n\nThe CV is constructed as follows:\n\n![conceptual flow chart](docs/images/concept-flow-chart.svg)\n\nThese components may be controlled using the `ancv` field in your `resume.json`:\n\n```json\n{\n   "basics": {},\n   "education": [],\n   "meta": {\n     "ancv": {\n        "template": "Sequential",\n        "theme": "basic",\n        "ascii_only": false,\n        "language": "en"\n     }\n   }\n}\n```\n\nThe shown values are the default ones.\nAll fields, including the `ancv` one itself, are optional, and the above defaults will be set for omitted fields.\nThis means **a [valid JSON resume](https://github.com/jsonresume/resume-schema/blob/master/schema.json) (without an `ancv` section) is also valid here**.\nThe currently available options can be printed out:\n\n```bash\n$ pip install ancv >> /dev/null && ancv list\nComponents\n├── Templates\n│   └── Sequential\n├── Themes\n│   ├── plain\n│   └── basic\n└── Translations\n    ├── en\n    └── de\n```\n\n## Installation as a library\n\nFor local use, install the package as usual.\nNote that it\'s pretty heavy on the dependencies.\n\n```bash\npip install ancv\n```\n---\n\n<p align="center">\n   <a href="https://github.com/alexpovel/ancv">\n     <img src="https://github.githubassets.com/images/modules/site/icons/footer/github-mark.svg" alt="github logo">\n   </a>\n</p>\n',
    'author': 'Alex Povel',
    'author_email': 'python@alexpovel.de',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://ancv.io',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
